==> haskell-arrows-0.4.4.2-163-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arrows
version:              0.4.4.2
visibility:           public
id:                   arrows-0.4.4.2-9iELCgirele6C9hhreR4fr
key:                  arrows-0.4.4.2-9iELCgirele6C9hhreR4fr
license:              BSD-3-Clause
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
author:               Ross Paterson <R.Paterson@city.ac.uk>
homepage:             http://www.haskell.org/arrows/
synopsis:             Arrow classes and transformers
description:
    Several classes that extend the Arrow class, and some
    transformers that implement or lift these classes.

category:             Control
abi:                  91866d886687080fcb8da9d3a840085b
exposed:              True
exposed-modules:
    Control.Arrow.Operations Control.Arrow.Transformer
    Control.Arrow.Transformer.All Control.Arrow.Transformer.Automaton
    Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
    Control.Arrow.Transformer.Reader Control.Arrow.Transformer.State
    Control.Arrow.Transformer.Static Control.Arrow.Transformer.Stream
    Control.Arrow.Transformer.Writer

hidden-modules:       Control.Arrow.Internals
import-dirs:          /usr/lib/ghc-9.4.8/site-local/arrows-0.4.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arrows-0.4.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arrows-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arrows
hs-libraries:         HSarrows-0.4.4.2-9iELCgirele6C9hhreR4fr
depends:              Stream-0.4.7.2-EtU7rHTrTe34advlE3E0Or base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-arrows/html/arrows.haddock
haddock-html:         /usr/share/doc/haskell-arrows/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-arrows-0.4.4.2-164-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arrows.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arrows
version:              0.4.4.2
visibility:           public
id:                   arrows-0.4.4.2-A29QDjrE0fZHSFRxzY5bLe
key:                  arrows-0.4.4.2-A29QDjrE0fZHSFRxzY5bLe
license:              BSD-3-Clause
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
author:               Ross Paterson <R.Paterson@city.ac.uk>
homepage:             http://www.haskell.org/arrows/
synopsis:             Arrow classes and transformers
description:
    Several classes that extend the Arrow class, and some
    transformers that implement or lift these classes.

category:             Control
abi:                  ed9a5e374ea0f7fc9e7b41e3d67f4e2c
exposed:              True
exposed-modules:
    Control.Arrow.Operations Control.Arrow.Transformer
    Control.Arrow.Transformer.All Control.Arrow.Transformer.Automaton
    Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
    Control.Arrow.Transformer.Reader Control.Arrow.Transformer.State
    Control.Arrow.Transformer.Static Control.Arrow.Transformer.Stream
    Control.Arrow.Transformer.Writer

hidden-modules:       Control.Arrow.Internals
import-dirs:          /usr/lib/ghc-9.4.8/site-local/arrows-0.4.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arrows-0.4.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arrows-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arrows
hs-libraries:         HSarrows-0.4.4.2-A29QDjrE0fZHSFRxzY5bLe
depends:              Stream-0.4.7.2-35XAApPLicvH2aIdRQ0I6x base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-arrows/html/arrows.haddock
haddock-html:         /usr/share/doc/haskell-arrows/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
